#  Drakkar-Software OctoBot-Trading
#  Copyright (c) Drakkar-Software, All rights reserved.
#
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 3.0 of the License, or (at your option) any later version.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public
#  License along with this library.
import dataclasses
import typing

import octobot_commons.enums as commons_enums


@dataclasses.dataclass
class ChannelSpecs:
    channel: str
    symbol: typing.Optional[str] = dataclasses.field(default=None)
    time_frame: typing.Optional[commons_enums.TimeFrames] = dataclasses.field(default=None)

    def __hash__(self):
        return hash((self.channel, self.symbol, self.time_frame))
